//  IoT電子工作キット sLab-Remo2
//  2-2-1.超音波センサ

// ①利用ピンの設定
const byte ONPA_TRIG    =  13;  // 超音波トリガー
const byte ONPA_ECHO    =  12;  // 超音波エコー

// ②起動時、最初に実行される処理
void setup() {
  Serial.begin(115200);        // シリアルモニタ設定（115200bps）
  Serial.println();            // (見やすくするために改行)
  // ③TRIGに出力、ECHOに入力ピン設定
  pinMode(ONPA_TRIG, OUTPUT);
  pinMode(ONPA_ECHO, INPUT);
}

// ④setup完了後、電源OFFまで繰り返し処理
void loop() {
  // ⑤超音波センサで距離測定
  checkSensor(ONPA_TRIG, ONPA_ECHO);
  // ⑥3秒間間隔を空けて測定
  delay(3000);
}

// ⑦センサー情報取得
String checkSensor(byte trigPin, byte echoPin){
  // ⑧超音波を発して物体に当って跳ね返ってきた時間
  int duration;
  // ⑨物体との距離
  float distance;
  // ⑩TrigピンをLOWに設定してリセット
  digitalWrite(trigPin, LOW);
  // ⑪1μ秒処理を止める
  delayMicroseconds(1);
  // ⑫TrigピンをHIGHに設定
  digitalWrite(trigPin, HIGH);
  // ⑬10μ秒処理を止める（トリガーPinをHIGHで10μ秒送信）
  delayMicroseconds(10);
  // ⑭TrigピンをLOWに設定
  digitalWrite(trigPin, LOW);
  // ⑮超音波を発して物体に当って跳ね返ってきた時間(μ秒)を取得(LOW=>HIGHまでの時間)
  duration = pulseIn(echoPin, HIGH);
  // ⑯取得した時間は往復時間のため2で割る
  distance = duration / 2;
  // ⑰測定時間から距離(cm)を算出(音速は340m/s)
  distance = distance / 1000000 * 340 * 100;
  // ⑱シリアルモニターに表示
  Serial.print(String(echoPin) + "_Duration: ");
  Serial.print(duration);
  Serial.print(" usec ");
  Serial.print(" Distance: ");
  Serial.print(distance);
  Serial.println(" cm");
  // ⑲測定結果を返答
  return String (distance);
}
