// ①WebServer設定処理
void setup_webserver() {
  // ②WebServer処理設定（制御画面を送信）
  webServer.on("/", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "Top" );
      request->send(SPIFFS, "/top.html", "text/html");
  });
  webServer.on("/favicon.ico", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "favicon" );
      request->send(SPIFFS, "/favicon.ico", "image/x-icon");
  });
  // ③WebServerLED制御（LED制御）
  webServer.on("/led", HTTP_GET, [](AsyncWebServerRequest *request){
      String setLedVal = request->getParam("o")->value();
      if (setLedVal == "ON") {
        digitalWrite ( LED_PIN, true );
        Serial.println ( "led on" );
      } else {
        digitalWrite ( LED_PIN, false );
        Serial.println ( "led off" );
      }
      request->send(200, "text/plain", "OK");
  });
  // ④WebServer処理設定（制画面のJavascriptを送信）
  webServer.on("/rem.js", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "js" );
      request->send(SPIFFS, "/rem.js", "text/html");
  });
  // ⑤WebServer処理設定（設定画面を送信）
  webServer.on("/set", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "set" );
      request->send(SPIFFS, "/set.html", "text/html");
  });
  // ⑦WebServer処理設定（ボタン情報送信）
  webServer.on("/getrem", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "getrem" );
      getRemocon(request);
  });
  // ⑧WebServer処理設定（リモコン受信設定）
  webServer.on("/setrem", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "setrem" );
      setRemocon(request);
  });
  // ⑨WebServer処理設定（リモコン送信）
  webServer.on("/cntrem", HTTP_GET, [](AsyncWebServerRequest *request){
      Serial.println ( "cntrem" );
      // ⑩ボタン番号を取得とチェック(HTTP GETリクエストのパラメータ)及び送信処理
      if (request->hasParam("n") && contRemocon( request->getParam("n")->value() )) {
        request->send(200, "text", "OK");
        Serial.println("Web send OK");
      } else {
        request->send(200, "text", "NG");
        Serial.println("Web send NG");
      }
  });
  // ⑪WebServer開始処理
  DefaultHeaders::Instance().addHeader("Access-Control-Allow-Origin", "*");
  webServer.begin();
  Serial.println ( "Web server started" );
}

// ⑫ボタン情報送信関数
void getRemocon(AsyncWebServerRequest *request) {
  // ⑬送信データを作成(JSON形式)
  String senddata = "{";
  // ⑭EEPROMデータを保存する変数を宣言
  st_remocon remRom;
  // ⑮ボタン情報10個分を読み出し返答する
  for (byte i = 0; i < 10; i++) {
    // ⑯EEPROMメモリ位置を計算
    int memPos = (65 * i);
    // ⑰前回の値'O:'が残らないように消す
    remRom.remo_name[0] = 'n';
    // ⑱EEPROMからデータ取得
    EEPROM.get<st_remocon>(memPos, remRom);
    // ⑲データが保存されているかCheck
    if (remRom.remo_name[0] == 'O' && remRom.remo_name[1] == ':' ) {
      // ⑳返答文字列長が１を超える場合は","をつける（２つ目以降との区切り）
      if (senddata.length() > 1) {
        senddata += ",";
      }
      // ㉑返答する値を一度String型に置き換える（"O:"を削除するため）
      String getirname = String(remRom.remo_name);
      // ㉒返答文字列作成（"O:"を削除するため2から最後まで）
      senddata += "\"" + (String)i + "\":\"" + getirname.substring(2,getirname.length()) + "\"";
    }
  }
  // ㉓最後にJSONデータを閉じるため"}"をつける
  senddata += "}";
  // ㉔作成した返答（JSON）データをWebサーバから返答する
  request->send(200, "text", senddata);
  Serial.println( "getRemocon:" + senddata);
}
